import _pymovex

def connect(*args, **kwargs):
    return _pymovex.connect(*args, **kwargs)

def fquery(*args, **kwargs):
    return _pymovex.fquery(*args, **kwargs)

def fquery_single(*args, **kwargs):
    return _pymovex.fquery_single(*args, **kwargs)

def close(*args, **kwargs):
    return _pymovex.close(*args, **kwargs)

def query(cmd, args):
    ffargs=[]
    for value, length in args:
        ffargs.append(("%%-%ss" % length) % value)
    fargs = "".join(ffargs)
    query = "%-15s%s" % (cmd, fargs)
    return _pymovex.query(query)

def rawquery(query):
    return _pymovex.query(query)

def maxrec(num):
    query("SetLstMaxRec", ((num, 11),))



from distutils.core import setup, Extension
import glob

_pymovex = Extension('_pymovex', sources = ['_pymovex.c'], libraries=['MvxSock'])

setup(name='pymovex',
      version='1.0',
      description="Python module for interacting with M3/Movex, implemented using the C-API",
      py_modules=['pymovex'],
      ext_modules=[_pymovex],
      author='Jean-Baptiste Quenot',
      author_email='jbq@caraldi.com',
      url="http://github.com/jbq/pymovex",
      scripts=glob.glob("tests/*")
    )
